```{include} ../README.md
:relative-docs: docs/
:start-after: <!-- INDEX-START -->
```

## Table of Contents

```{toctree}
:maxdepth: 1
install.md
text-notebooks.md
paired-notebooks.md
jupyterlab-extension.md
config.md
advanced-options.md
formats-scripts.md
formats-markdown.md
languages.md
using-cli.md
using-pre-commit.md
faq.md
tutorials.md
contributing.md
developing.md
changelog.md
```
